@@ -569,7 +569,7 @@ KPrefsWidPath::KPrefsWidPath(KConfigSkeleton::ItemPath *item, QWidget *parent, c
     mURLRequester = new KUrlRequester(parent);
     mLabel->setBuddy(mURLRequester);
     mURLRequester->setMode(mode);
-    mURLRequester->setFilter(filter);
+    mURLRequester->setNameFilter(filter);
     connect(mURLRequester, &KUrlRequester::textChanged, this, &KPrefsWidPath::changed);
     QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
@@ -866,27 +866,18 @@ void KPrefsDialog::slotDefault()
     if (KMessageBox::warningContinueCancel(this,
                                            i18n("You are about to set all preferences to default values. "
                                                 "All custom modifications will be lost."),
-                                           i18n("Setting Default Preferences"),
+                                           i18nc("@title:window", "Setting Default Preferences"),
                                            KGuiItem(i18n("Reset to Defaults")))
         == KMessageBox::Continue) {
         setDefaults();
     }
 }
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KPrefsModule::KPrefsModule(KConfigSkeleton *prefs, QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-KPrefsModule::KPrefsModule(KConfigSkeleton *prefs, QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+KPrefsModule::KPrefsModule(KConfigSkeleton *prefs, QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , KPrefsWidManager(prefs)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KPrefsModule::addWid(KPrefsWid *wid)
@@ -897,22 +888,14 @@ void KPrefsModule::addWid(KPrefsWid *wid)
 
 void KPrefsModule::slotWidChanged()
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     setNeedsSave(true);
-#endif
 }
 
 void KPrefsModule::load()
 {
     readWidConfig();
     usrReadConfig();
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KPrefsModule::save()
@@ -924,9 +907,7 @@ void KPrefsModule::save()
 void KPrefsModule::defaults()
 {
     setWidDefaults();
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     setNeedsSave(true);
-#endif
 }
+
+#include "moc_kprefsdialog.cpp"
